@@ -1,7 +1,7 @@
 package WebService::Client;
 use Moo::Role;
 
-our $VERSION = '0.0204'; # VERSION
+our $VERSION = '0.0300'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw(DELETE GET POST PUT);
@@ -39,7 +39,17 @@ sub get {
     my $url = $self->_url($path);
     my $q = '';
     if (%$params) {
-        $q = '?' . join '&', map { "$_=$params->{$_}" } keys %$params;
+        my @items;
+        while (my ($key, $value) = each %$params) {
+            if ('ARRAY' eq ref $value) {
+                push @items, map "$key\[]=$_", @$value;
+            } else {
+                push @items, "$key=$value";
+            }
+        }
+        if (@items) {
+            $q = '?' . join '&', @items;
+        }
     }
     return $self->req(GET "$url$q", %$headers);
 }
@@ -149,7 +159,7 @@ WebService::Client - A base role for quickly and easily creating web service cli
 
 =head1 VERSION
 
-version 0.0204
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -220,6 +230,8 @@ argument that is a hashref of custom headers.
 =head2 get
 
     $client->get('/foo');
+    $client->get('/foo', { query => 'params' });
+    $client->get('/foo', { query => [qw(array params)] });
 
 Makes an HTTP POST request.
 
